/*
 * This file is part of Maliit plugins
 *
 * Copyright (C) Jakub Pavelek <jpavelek@live.com>
 *
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 *
 * Redistributions of source code must retain the above copyright notice, this list
 * of conditions and the following disclaimer.
 * Redistributions in binary form must reproduce the above copyright notice, this list
 * of conditions and the following disclaimer in the documentation and/or other materials
 * provided with the distribution.
 * Neither the name of Nokia Corporation nor the names of its contributors may be
 * used to endorse or promote products derived from this software without specific
 * prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL
 * THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 */


.pragma library

var BG_COLOR = "black";
var LANDSCAPE_WIDTH = 800;
var LANDSCAPE_HEIGHT = 230;
var PORTRAIT_WIDTH = 480;
var PORTRAIT_HEIGHT = 320;

var landscapeWidth = 78
var landscapeHeight = 58
var landscapeHorizontalPadding = 3
var landscapeVerticalPadding = 6

var portraitWidth = 48
var portraitHeight = 80
var portraitHorizontalPadding = 4
var portraitVerticalPadding = 10

var PORTRAIT_NARROW_OTT_WIDTH = 60;
var PORTRAIT_OTT_WIDTH = 88;
var PORTRAIT_SHIFT_WIDTH = 52;
var FONT_SIZE_RUSSIAN = 18;

var FONT_SIZE = 28;
var TEXT_COLOR = "white";
var FONT_SIZE_POPPER = 56;
var TEXT_COLOR_POPPER = "black";

var FLICK_CLOSE_DISTANCE = 60;
